@@ -25,8 +25,8 @@ setClass("phylo4",
                         annote = "list"),
          prototype = list(
                         edge = matrix(nrow = 0, ncol = 2,
-                            dimname = list(NULL, c("ancestor", "descendant"))),
-                        edge.length = numeric(0),
+                            dimnames = list(NULL, c("ancestor", "descendant"))),
+           edge.length = numeric(0),
                         label = character(0),
                         edge.label = character(0),
                         order = "unknown",
