@@ -3,10 +3,10 @@
 #
 
 ### Get all the test files
-if (Sys.getenv("RCMDCHECK") == FALSE) {
+if (is.na(Sys.getenv("R_CMD_CHECK", unset = NA))) {
     pth <- file.path(getwd(), "..", "inst", "nexusfiles")
 } else {
-    pth <- system.file(package="phylobase", "nexusfiles")
+    pth <- system.file(package = "phylobase", "nexusfiles")
 }
 
 ## co1.nex -- typical output from MrBayes. Contains 2 identical trees, the first
